#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
using System.IO;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
    [Gui.CategoryOrder("Options", 10)]
    [Gui.CategoryOrder("Levels", 20)]
    [Gui.CategoryOrder("Settings", 30)]

    public class MenthorQLevels : Indicator
    {
        // v1 = initial version (15-MAY-2024)
        // v2 = revision (20-MAY-2024)
        // v3 = revision (20-MAY-2024)
        // v4 = revision (21-MAY-2024)
        // v5 = revision to show price (22-MAY-2024)
        // v6 = revision (22-MAY-2024)
        // v7 = signed off (25-MAY-2024)
        // v8 = order #FO41EDB24FC86 (27-MAY-2024)
        // v9 = order #FO8317E7E7F08 - no license check (7-JUN-2024)

        #region Variables
        private string codeUpdated = "Last updated: 7-JUN-2024";
        private string codeVers = "v9";
        private string codeAuthor = "Author: www.fiverr.com/codernt8";
        private string codeFor = "For: ruggio1";
        private string codeOrder = "Order Ref: # FO1625BBAA01";
        private string codeProductName = "Product Name: MenthorQLevels";
        private string levelText;

        #endregion

        #region Config
        public override string DisplayName
        {
            get { return Name; }
        }
        #endregion

        protected override void OnStateChange()
        {
            if (State == State.SetDefaults)
            {
                Name = "Menthor Q Levels";
                Calculate = Calculate.OnBarClose;
                IsOverlay = true;
                IsAutoScale = false;
                myFont = new SimpleFont("Calibri", 14);
                versionInfo = codeVers + " " + codeUpdated;
                lineColor = Brushes.SeaGreen;
                labelBackgroundColor = Brushes.OrangeRed;
                lineWidth = 2;
                lineType = DashStyleHelper.Dash;
                labelOffset = 7;
                labelsOpacity = 45;
                showCallResistance = showPutSupport = showHVL = show1DMin = show1DMax 
                    = showCallResistance0DTE = showPutSupport0DTE = showHVL0DTE = showGammaWall0DTE 
                    = showGEX1 = showGEX2 = showGEX3 = showGEX4 = showGEX5 = showGEX6 = showGEX7 
                    = showGEX8 = showGEX9 = showGEX10 = true;
            }
            else if (State == State.DataLoaded)
            {
                if (showOutput) PrintSettings();

                // Load text from file
                string filePath = levelsTextFile;
                levelText = LoadTextFromFile(filePath);

                var data = DataParser.ParseData(levelText, Instrument, this);

                // Access the data
                if (data.ContainsKey(Instrument.FullName))
                {
                    if (showOutput)
                    {
                        Print("---------------------");
                        Print("Instrument found: " + Instrument.FullName);
                    }
                    var pairs = data[Instrument.FullName];
                    foreach (var pair in pairs)
                    {
                        if (showOutput) Print("Label: " + pair.Item1 + ", Price: " + pair.Item2);
                        var line = DrawLL.LabeledHorizontalLine(this, pair.Item1, pair.Item2, lineColor, lineType, lineWidth);
                        line.Font = myFont;
                        line.IsAutoScale = IsAutoScale;
                        line.DisplayText = (!showPrice) ? pair.Item1 : pair.Item1 + ": " + pair.Item2;
                        line.AppendPriceTime = false;
                        line.VerticalOffset = labelOffset;
                        line.BackgroundBrush = labelBackgroundColor;
                        line.OutlineStroke.Brush = labelBackgroundColor;
                        line.AreaOpacity = labelsOpacity;
                    }
                }
            }
        }

        private string LoadTextFromFile(string filePath)
        {
            try
            {
                return File.ReadAllText(filePath);
            }
            catch (Exception ex)
            {
                Print("Error loading text from file: " + ex.Message);
                return string.Empty;
            }
        }

        protected override void OnBarUpdate()
        {
            if (CurrentBar < BarsRequiredToPlot)
                return;
        }

        public class DataParser
        {
            public static Dictionary<string, List<Tuple<string, double>>> ParseData(string input, Instrument currentInstrument, MenthorQLevels indicator)
            {
                var result = new Dictionary<string, List<Tuple<string, double>>>();

                // Split the input string by both CR LF and LF
                var lines = input.Split(new[] { "\r\n", "\n" }, StringSplitOptions.RemoveEmptyEntries);
                foreach (var line in lines)
                {
                    indicator.Print("Line: " + line); // Print the entire line
                    var parts = line.Split(new[] { ':' }, 2); // Split only at the first colon
                    indicator.Print("Parts: " + parts.Length);
                    if (parts.Length == 2)
                    {
                        var instrumentId = parts[0].Trim();
                        var instrument = Instrument.GetInstrument(instrumentId);

                        // Add print statements to output the variables
                        if (indicator.showOutput)
                        {
                            if (instrumentId != null) indicator.Print("Instrument ID from text file: " + instrumentId);
                            else indicator.Print("Instrument ID from text file was null");
                            if (instrument != null) indicator.Print("Instrument from Ninjatrader: " + instrument.FullName);
                            else indicator.Print("Instrument ID from text file did not match with any instrument on Ninjatrader");
                        }

                        if (instrument == currentInstrument)
                        {
                            var data = parts[1].Split(',').Select(x => x.Trim()).ToList();
                            var priceLabelDict = new Dictionary<double, List<string>>();

                            for (int i = 0; i < data.Count; i += 2)
                            {
                                if (i + 1 < data.Count)
                                {
                                    double price;
                                    if (double.TryParse(data[i + 1], out price))
                                    {
                                        if (indicator.ShouldShowLabel(data[i]))
                                        {
                                            if (!priceLabelDict.ContainsKey(price))
                                            {
                                                priceLabelDict[price] = new List<string>();
                                            }
                                            priceLabelDict[price].Add(data[i]);
                                        }
                                    }
                                }
                            }

                            List<Tuple<string, double>> pairs = new List<Tuple<string, double>>();
                            foreach (var kvp in priceLabelDict)
                            {
                                string labels = string.Join(" & ", kvp.Value);
                                pairs.Add(Tuple.Create(labels, kvp.Key));
                            }
                            result[instrument.FullName] = pairs; // Use instrument.FullName as the key
                        }
                    }
                }

                return result;
            }
        }

        #region Properties
        [NinjaScriptProperty]
        [Display(Name = "NinjaScript Output", Description = "", Order = 10, GroupName = "Settings")]
        public bool showOutput
        { get; set; }

        [NinjaScriptProperty]
        [ReadOnly(true)]
        [Display(Name = "Version:", Description = "", Order = 20, GroupName = "Settings")]
        public string versionInfo
        { get; set; }

        [PropertyEditor("NinjaTrader.Gui.Tools.FilePathPicker", Filter = "TXT Files (*.txt)|*.txt")]
        [NinjaScriptProperty]
        [Display(Name = "Levels Text File", Description = "", Order = 10, GroupName = "Options")]
        public string levelsTextFile
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Labels Font", Description = "", Order = 30, GroupName = "Options")]
        public NinjaTrader.Gui.Tools.SimpleFont myFont { get; set; }

        [XmlIgnore()]
        [Display(Name = "Label Background", Order = 40, GroupName = "Options")]
        public System.Windows.Media.Brush labelBackgroundColor
        { get; set; }
        [Browsable(false)]
        public string labelBackgroundColorT
        {
            get { return Serialize.BrushToString(labelBackgroundColor); }
            set { labelBackgroundColor = Serialize.StringToBrush(value); }
        }

        [NinjaScriptProperty]
        [Display(Name = "Labels Opacity", Description = "", Order = 50, GroupName = "Options")]
        public int labelsOpacity { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Label Offset (ticks)", Description = "", Order = 60, GroupName = "Options")]
        public int labelOffset { get; set; }

        [XmlIgnore()]
        [Display(Name = "Line Color", Order = 80, GroupName = "Options")]
        public System.Windows.Media.Brush lineColor
        { get; set; }
        [Browsable(false)]
        public string lineColorT
        {
            get { return Serialize.BrushToString(lineColor); }
            set { lineColor = Serialize.StringToBrush(value); }
        }

        [NinjaScriptProperty]
        [Display(Name = "Line Type", Description = "", Order = 90, GroupName = "Options")]
        public DashStyleHelper lineType
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Line Width", Description = "", Order = 100, GroupName = "Options")]
        public int lineWidth
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Show Price", Description = "", Order = 110, GroupName = "Options")]
        public bool showPrice
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Call Resistance", Description = "", Order = 10, GroupName = "Levels")]
        public bool showCallResistance
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Put Support", Description = "", Order = 11, GroupName = "Levels")]
        public bool showPutSupport
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "HVL", Description = "", Order = 12, GroupName = "Levels")]
        public bool showHVL
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "1D Min", Description = "", Order = 13, GroupName = "Levels")]
        public bool show1DMin
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "1D Max", Description = "", Order = 14, GroupName = "Levels")]
        public bool show1DMax
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Call Resistance 0DTE", Description = "", Order = 15, GroupName = "Levels")]
        public bool showCallResistance0DTE
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Put Support 0DTE", Description = "", Order = 16, GroupName = "Levels")]
        public bool showPutSupport0DTE
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "HVL 0DTE", Description = "", Order = 17, GroupName = "Levels")]
        public bool showHVL0DTE
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "Gamma Wall 0DTE", Description = "", Order = 18, GroupName = "Levels")]
        public bool showGammaWall0DTE
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 1", Description = "", Order = 19, GroupName = "Levels")]
        public bool showGEX1
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 2", Description = "", Order = 20, GroupName = "Levels")]
        public bool showGEX2
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 3", Description = "", Order = 21, GroupName = "Levels")]
        public bool showGEX3
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 4", Description = "", Order = 22, GroupName = "Levels")]
        public bool showGEX4
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 5", Description = "", Order = 23, GroupName = "Levels")]
        public bool showGEX5
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 6", Description = "", Order = 24, GroupName = "Levels")]
        public bool showGEX6
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 7", Description = "", Order = 25, GroupName = "Levels")]
        public bool showGEX7
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 8", Description = "", Order = 26, GroupName = "Levels")]
        public bool showGEX8
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 9", Description = "", Order = 27, GroupName = "Levels")]
        public bool showGEX9
        { get; set; }

        [NinjaScriptProperty]
        [Display(Name = "GEX 10", Description = "", Order = 28, GroupName = "Levels")]
        public bool showGEX10
        { get; set; }
        #endregion

        #region Helpers 
        public bool ShouldShowLabel(string label)
        {
            switch (label)
            {
                case "Call Resistance": return showCallResistance;
                case "Put Support": return showPutSupport;
                case "HVL": return showHVL;
                case "1D Min": return show1DMin;
                case "1D Max": return show1DMax;
                case "Call Resistance 0DTE": return showCallResistance0DTE;
                case "Put Support 0DTE": return showPutSupport0DTE;
                case "HVL 0DTE": return showHVL0DTE;
                case "Gamma Wall 0DTE": return showGammaWall0DTE;
                case "GEX 1": return showGEX1;
                case "GEX 2": return showGEX2;
                case "GEX 3": return showGEX3;
                case "GEX 4": return showGEX4;
                case "GEX 5": return showGEX5;
                case "GEX 6": return showGEX6;
                case "GEX 7": return showGEX7;
                case "GEX 8": return showGEX8;
                case "GEX 9": return showGEX9;
                case "GEX 10": return showGEX10;
                default: return false;
            }
        }

        private void PrintSettings()
        {
            Print("#########################################################");
            Print(codeAuthor);
            Print(codeFor);
            Print(codeOrder);
            Print(codeProductName);
            Print(codeUpdated);
            Print(codeVers);
            Print("#########################################################");
            Print("Indicator enabled: " + DateTime.Now);
            Print("Indicator Settings...");
            Print(this.ChartBars);
            Print("Timeframe: " + BarsPeriod.BarsPeriodTypeName + " Type #" + BarsPeriod.BarsPeriodTypeSerialize + " Value: " + BarsPeriod.BaseBarsPeriodValue + " Time Period: " + BarsPeriod.Value + " Value 2: " + BarsPeriod.Value2);
            Print("Bars on chart: " + Count);
            Print("Timezone: " + Core.Globals.GeneralOptions.TimeZoneInfo);
            Print("Install folder: " + NinjaTrader.Core.Globals.InstallDir);
            Print("User directory: " + NinjaTrader.Core.Globals.UserDataDir);
            Print("---------------------------------------------------------");
            Print("Settings - NinjaScript Output: " + showOutput);
            Print("Settings - Version: " + versionInfo);
            Print("Options - Levels Text File: " + levelsTextFile);
            Print("Options - Labels Font: " + GetFontInfo(myFont));
            Print("Options - Label Background: " + GetBrushName(labelBackgroundColor));
            Print("Options - Labels Opacity: " + labelsOpacity);
            Print("Options - Label Offset (ticks): " + labelOffset);
            Print("Options - Line Color: " + GetBrushName(lineColor));
            Print("Options - Line Type: " + lineType);
            Print("Options - Line Width: " + lineWidth);
            Print("Options - Show Price: " + showPrice);
            Print("Levels - Call Resistance: " + showCallResistance);
            Print("Levels - Put Support: " + showPutSupport);
            Print("Levels - HVL: " + showHVL);
            Print("Levels - 1D Min: " + show1DMin);
            Print("Levels - 1D Max: " + show1DMax);
            Print("Levels - Call Resistance 0DTE: " + showCallResistance0DTE);
            Print("Levels - Put Support 0DTE: " + showPutSupport0DTE);
            Print("Levels - HVL 0DTE: " + showHVL0DTE);
            Print("Levels - Gamma Wall 0DTE: " + showGammaWall0DTE);
            Print("Levels - GEX 1: " + showGEX1);
            Print("Levels - GEX 2: " + showGEX2);
            Print("Levels - GEX 3: " + showGEX3);
            Print("Levels - GEX 4: " + showGEX4);
            Print("Levels - GEX 5: " + showGEX5);
            Print("Levels - GEX 6: " + showGEX6);
            Print("Levels - GEX 7: " + showGEX7);
            Print("Levels - GEX 8: " + showGEX8);
            Print("Levels - GEX 9: " + showGEX9);
            Print("Levels - GEX 10: " + showGEX10);
            Print("---------------------------------------------------------");
        }

        public string GetBrushName(Brush brush)
        {
            SolidColorBrush solidColorBrush = brush as SolidColorBrush;
            if (solidColorBrush == null) return "Not a SolidColorBrush";

            string colorString = solidColorBrush.Color.ToString();

            foreach (var colorProperty in typeof(Colors).GetProperties())
            {
                if (colorProperty.PropertyType == typeof(Color))
                {
                    Color color = (Color)colorProperty.GetValue(null);
                    if (color.ToString() == colorString)
                    {
                        return colorProperty.Name;
                    }
                }
            }

            // No matching named color found, return the original color string
            return colorString;
        }

        public string GetFontInfo(SimpleFont font)
        {
            if (font != null)
            {
                string fontName = font.Family.ToString();
                double fontSize = font.Size;
                bool isBold = font.Bold;
                bool isItalic = font.Italic;

                string fontDetails = fontName + ", Font Size: " + fontSize + ", Is Bold: " + isBold + ", Is Italic: " + isItalic;
                return fontDetails;
            }
            else
            {
                return "Font is null.";
            }
        }
        #endregion
    }

}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private MenthorQLevels[] cacheMenthorQLevels;
		public MenthorQLevels MenthorQLevels(bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			return MenthorQLevels(Input, showOutput, versionInfo, levelsTextFile, myFont, labelsOpacity, labelOffset, lineType, lineWidth, showPrice, showCallResistance, showPutSupport, showHVL, show1DMin, show1DMax, showCallResistance0DTE, showPutSupport0DTE, showHVL0DTE, showGammaWall0DTE, showGEX1, showGEX2, showGEX3, showGEX4, showGEX5, showGEX6, showGEX7, showGEX8, showGEX9, showGEX10);
		}

		public MenthorQLevels MenthorQLevels(ISeries<double> input, bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			if (cacheMenthorQLevels != null)
				for (int idx = 0; idx < cacheMenthorQLevels.Length; idx++)
					if (cacheMenthorQLevels[idx] != null && cacheMenthorQLevels[idx].showOutput == showOutput && cacheMenthorQLevels[idx].versionInfo == versionInfo && cacheMenthorQLevels[idx].levelsTextFile == levelsTextFile && cacheMenthorQLevels[idx].myFont == myFont && cacheMenthorQLevels[idx].labelsOpacity == labelsOpacity && cacheMenthorQLevels[idx].labelOffset == labelOffset && cacheMenthorQLevels[idx].lineType == lineType && cacheMenthorQLevels[idx].lineWidth == lineWidth && cacheMenthorQLevels[idx].showPrice == showPrice && cacheMenthorQLevels[idx].showCallResistance == showCallResistance && cacheMenthorQLevels[idx].showPutSupport == showPutSupport && cacheMenthorQLevels[idx].showHVL == showHVL && cacheMenthorQLevels[idx].show1DMin == show1DMin && cacheMenthorQLevels[idx].show1DMax == show1DMax && cacheMenthorQLevels[idx].showCallResistance0DTE == showCallResistance0DTE && cacheMenthorQLevels[idx].showPutSupport0DTE == showPutSupport0DTE && cacheMenthorQLevels[idx].showHVL0DTE == showHVL0DTE && cacheMenthorQLevels[idx].showGammaWall0DTE == showGammaWall0DTE && cacheMenthorQLevels[idx].showGEX1 == showGEX1 && cacheMenthorQLevels[idx].showGEX2 == showGEX2 && cacheMenthorQLevels[idx].showGEX3 == showGEX3 && cacheMenthorQLevels[idx].showGEX4 == showGEX4 && cacheMenthorQLevels[idx].showGEX5 == showGEX5 && cacheMenthorQLevels[idx].showGEX6 == showGEX6 && cacheMenthorQLevels[idx].showGEX7 == showGEX7 && cacheMenthorQLevels[idx].showGEX8 == showGEX8 && cacheMenthorQLevels[idx].showGEX9 == showGEX9 && cacheMenthorQLevels[idx].showGEX10 == showGEX10 && cacheMenthorQLevels[idx].EqualsInput(input))
						return cacheMenthorQLevels[idx];
			return CacheIndicator<MenthorQLevels>(new MenthorQLevels(){ showOutput = showOutput, versionInfo = versionInfo, levelsTextFile = levelsTextFile, myFont = myFont, labelsOpacity = labelsOpacity, labelOffset = labelOffset, lineType = lineType, lineWidth = lineWidth, showPrice = showPrice, showCallResistance = showCallResistance, showPutSupport = showPutSupport, showHVL = showHVL, show1DMin = show1DMin, show1DMax = show1DMax, showCallResistance0DTE = showCallResistance0DTE, showPutSupport0DTE = showPutSupport0DTE, showHVL0DTE = showHVL0DTE, showGammaWall0DTE = showGammaWall0DTE, showGEX1 = showGEX1, showGEX2 = showGEX2, showGEX3 = showGEX3, showGEX4 = showGEX4, showGEX5 = showGEX5, showGEX6 = showGEX6, showGEX7 = showGEX7, showGEX8 = showGEX8, showGEX9 = showGEX9, showGEX10 = showGEX10 }, input, ref cacheMenthorQLevels);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.MenthorQLevels MenthorQLevels(bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			return indicator.MenthorQLevels(Input, showOutput, versionInfo, levelsTextFile, myFont, labelsOpacity, labelOffset, lineType, lineWidth, showPrice, showCallResistance, showPutSupport, showHVL, show1DMin, show1DMax, showCallResistance0DTE, showPutSupport0DTE, showHVL0DTE, showGammaWall0DTE, showGEX1, showGEX2, showGEX3, showGEX4, showGEX5, showGEX6, showGEX7, showGEX8, showGEX9, showGEX10);
		}

		public Indicators.MenthorQLevels MenthorQLevels(ISeries<double> input , bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			return indicator.MenthorQLevels(input, showOutput, versionInfo, levelsTextFile, myFont, labelsOpacity, labelOffset, lineType, lineWidth, showPrice, showCallResistance, showPutSupport, showHVL, show1DMin, show1DMax, showCallResistance0DTE, showPutSupport0DTE, showHVL0DTE, showGammaWall0DTE, showGEX1, showGEX2, showGEX3, showGEX4, showGEX5, showGEX6, showGEX7, showGEX8, showGEX9, showGEX10);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.MenthorQLevels MenthorQLevels(bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			return indicator.MenthorQLevels(Input, showOutput, versionInfo, levelsTextFile, myFont, labelsOpacity, labelOffset, lineType, lineWidth, showPrice, showCallResistance, showPutSupport, showHVL, show1DMin, show1DMax, showCallResistance0DTE, showPutSupport0DTE, showHVL0DTE, showGammaWall0DTE, showGEX1, showGEX2, showGEX3, showGEX4, showGEX5, showGEX6, showGEX7, showGEX8, showGEX9, showGEX10);
		}

		public Indicators.MenthorQLevels MenthorQLevels(ISeries<double> input , bool showOutput, string versionInfo, string levelsTextFile, NinjaTrader.Gui.Tools.SimpleFont myFont, int labelsOpacity, int labelOffset, DashStyleHelper lineType, int lineWidth, bool showPrice, bool showCallResistance, bool showPutSupport, bool showHVL, bool show1DMin, bool show1DMax, bool showCallResistance0DTE, bool showPutSupport0DTE, bool showHVL0DTE, bool showGammaWall0DTE, bool showGEX1, bool showGEX2, bool showGEX3, bool showGEX4, bool showGEX5, bool showGEX6, bool showGEX7, bool showGEX8, bool showGEX9, bool showGEX10)
		{
			return indicator.MenthorQLevels(input, showOutput, versionInfo, levelsTextFile, myFont, labelsOpacity, labelOffset, lineType, lineWidth, showPrice, showCallResistance, showPutSupport, showHVL, show1DMin, show1DMax, showCallResistance0DTE, showPutSupport0DTE, showHVL0DTE, showGammaWall0DTE, showGEX1, showGEX2, showGEX3, showGEX4, showGEX5, showGEX6, showGEX7, showGEX8, showGEX9, showGEX10);
		}
	}
}

#endregion
